@@ -12,7 +12,7 @@ write new modules on the platform::
 """
 import os
 
-VERSION = '3.0.5'
+VERSION = '3.0.8'
 
 def _get_git_revision(path):
     revision_file = os.path.join(path, 'refs', 'heads', 'master')
@@ -52,4 +52,4 @@ from .services import *
 from .datasets import * 
 from .notebook import *
 from .quality import *
-from . import featurestore, realtime 
+from . import featurestore, realtime, contrib
