@@ -187,18 +187,15 @@ class Node(metaclass=NodeMeta):
         data_root = self.get_file("%(data_root)s/%(name)s", extra={
             'name': self.name
         })
-        self.testdata = {
-            'data_root': os.path.join(data_root, self.name),
-            'outputdir': os.path.join(data_root, self.name),
-            'inputdir': data_root,
-            'statedir': os.path.join(data_root, self.name, 'state'),
-            'global': {},
-            'datasets': {},
-            'data': {},
-            'conf': {}
-        }
+
+        self.testdata = self.get_testdata
         """dict: Test data to be used for testing module
 
+        The default structure is instantiated by self.get_testdata. Each 
+        of the elements (e.g., conf) can be specified by over-riding 
+        corresponding method (e.g., self.get_testdata_conf). Such 
+        functions are supported for conf, args, global, data.
+
         It has the form::
 
             {
@@ -384,6 +381,97 @@ class Node(metaclass=NodeMeta):
     #############################################
     # Helper functions
     #############################################
+    def get_testdata(self):
+        """
+        Generate test data structure
+
+        Returns:
+
+           testdata (dict) : Dictionary
+
+        """
+        test_root = os.environ['ENRICH_TEST']
+
+        return {
+            'data_root': os.path.join(test_root, self.name),
+            'inputdir': test_root,
+            'outputdir': os.path.join(test_root, self.name, 'output'),
+            'statedir': os.path.join(test_root, self.name, 'state'),
+            'conf': self.get_testdata_conf(),
+            'data': self.get_testdata_data(),
+            'global': self.get_testdata_global()
+        }
+
+    def get_testdata_conf(self):
+        """
+        Get testdata conf attribute
+
+        Returns
+        -------
+        dict: a dictionary of args and any other elements
+
+        """
+        return {
+            "args": self.get_testdata_args()
+        }
+
+    def get_testdata_args(self):
+        """
+        Get testdata args attribute of conf
+
+        Returns
+        -------
+        dict: a dictionary of args
+
+        """
+        return {}
+
+    def get_testdata_global(self):
+        """
+        Get testdata global attribute. Global args are pipeline-wide
+        args.
+
+        Returns
+        -------
+        dict: a dictionary of global args
+
+        Example::
+
+            return {
+               'args': {
+                    'rundate': '2020-01-01'
+                }
+             }
+
+        """
+        return {}
+
+    def get_testdata_data(self):
+        """
+        Get 'data' element of test data. This specifies
+        what dataframes have to be loaded to test this 
+        transform.
+
+        Returns
+        -------
+        dict: A specification of dataframes and loading instructions
+
+        Example::
+
+          return { 
+                'article': {
+                    'filename': 'test.csv',
+                    'transform': 'Core',
+                    'frametype': 'pandas',
+                    'stages': [ 'transform1'],
+                    'params': {
+                        'sep': ','
+                    }
+                }
+              }
+        """
+        return {}
+
     def is_enabled(self):
         """
         bool: Check whether this module is enabled
@@ -709,6 +797,8 @@ class Node(metaclass=NodeMeta):
 
         """
 
+        readonly = self.config.readonly
+
         # => Check whether internal configuration is valid
         self.preload_validate_self()
 
@@ -735,8 +825,11 @@ class Node(metaclass=NodeMeta):
         if 'role' in conf:
             self.roles_current = conf['role']
 
+        # Add a readonly check to avoid side effects of the enrichgui
+        # scanning the transform.
         if 'args' in conf:
-            self.args = self.preload_clean_args(conf['args'])
+            if not readonly:
+                self.args = self.preload_clean_args(conf['args'])
 
         if 'dependencies' in conf:
             self.dependencies = conf['dependencies']
@@ -994,7 +1087,7 @@ class Node(metaclass=NodeMeta):
         Looks up the siteconf in ENRICH_ETC and
         returns appropriate entry
 
-        This name should in specific in the credentials 
+        This name should in specific in the credentials
         section of siteconf.
         """
         if not hasattr(self.config, 'siteconf'):
