@@ -175,42 +175,87 @@ class RunBase(object):
                 nature = d.get('nature', 'unknown').lower().strip()
                 type_ = d.get('type', 'unknown').lower().strip()
 
+                if type_ in ['column', 'columns']:
+                    continue
+
                 objects = d.get('objects', d.get('name', []))
                 if not isinstance(objects, list) and not isinstance(objects, dict):
                     continue
 
-                isdict = isinstance(objects,dict)
-                for o in objects:
+                # Now clean and organize the dependencies...
+                """
+                    1. dependencies = [path1, path2..]
+                    2. dependencies = {
+                        "source1": path1,
+                        "source2": description2
+                    }
+                    3. dependencies = {
+                          "source1": {
+                             "transform": "Trial",
+                             "text": "...loan-s3/..."
+                           }
+                    }
+                """
+                cleaned_objects = {}
+                if isinstance(objects, list):
+                    # A list of files/text items
+                    for o in objects:
+                        label = os.path.basename(o) if "/" in o else o
+                        cleaned_objects[label] = {
+                            'transform': transform,
+                            'text': str(o)
+                        }
+                elif isinstance(objects, dict):
+                    for o, detail in objects.items():
+                        # A dictionary of name: <object>
+                        if isinstance(detail, str):
+                            # A dictionary of name: str
+                            cleaned_objects[o] = {
+                                'transform': transform,
+                                'text': detail
+                            }
+                        elif isinstance(detail, str):
+                            # A dictionary of name: list
+                            cleaned_objects[o] = {
+                                'transform': transform,
+                                'text': ",".join([str(s) for s in detail])
+                            }
+                        elif isinstance(detail, dict):
+                            # A dictionary of name: dict
+                            node_transform = detail.get('transform', transform)
+                            if 'text' in detail:
+                                text = detail['text']
+                            else:
+                                detail.pop('transform', None)
+                                text = str(detail)
+                            cleaned_objects[o] = {
+                                'transform': node_transform,
+                                'text': text
+                            }
 
-                    detail = objects[o] if isdict else o
-                    label = o
+                for label, detail in cleaned_objects.items():
+                    generator = detail['transform']
+                    text = detail['text']
+                    node = "{} ({})".format(label, generator)
 
                     if type_ in ['file']:
-                        label = label if isdict else os.path.basename(label)
-                        node = "{} ({}, {})".format(label, framename, transform)
-                        text = "Path: {}".format(detail)
+                        text = "Path/other: {}".format(text)
                     elif type_ in ['dataframe', 'dataframes']:
                         type_ = "dataframe"
-                        node_transform = last.get(label, transform)
+                        node_transform = last.get(label, generator)
                         node = "{} ({})".format(label, node_transform)
                         text = "Dataframe: {}".format(detail)
                     elif type_ in ['database', 'db', 'databases']:
                         type_ = "database"
-                        node_transform = last.get(label, transform)
-                        if "/" in label and (not isdict):
-                            node = "{} ({})".format(os.path.basename(label), transform)
-                        else:
-                            node = "{} ({})".format(label, transform)
-                        text = "DB: {}".format(detail)
+                        node_transform = last.get(label, generator)
+                        node = "{} ({})".format(label, node_transform)
+                        text = "DB: {}".format(text)
                     elif type_ in ['api', 'url']:
                         type_ = "url"
-                        node_transform = last.get(label, transform)
-                        if "/" in label and (not isdict):
-                            node = "{} (API, {})".format(os.path.basename(label), transform)
-                        else:
-                            node = "{} (API, {})".format(label, transform)
-                        text = "URL: {}".format(detail)
-                    elif type_ in ['columns']:
+                        node_transform = last.get(label, generator)
+                        node = "{} ({})".format(label, generator)
+                        text = "URL: {}".format(text)
+                    elif type_ in ['columns', 'column']:
                         continue
                     else:
                         logging.warning("Unknown Type: {}".format(type_))
@@ -327,6 +372,7 @@ class RunBase(object):
                         # (a) a list
                         # (b) a dict: name => str
                         # (c) a dict: name => list
+                        # (d) a dict: name => dict
                         objects = d.get('objects',{})
                         #print("Objects", objects)
                         if isinstance(objects, list):
@@ -595,6 +641,7 @@ class RunManagerBase(object):
         # Check if already present. If so, nothing to be done
         run = self.get_run(runid)
         if run is not None:
+            run.load()
             return
 
         logger.debug("RunID ({})missing in cache. Loading".format(runid),
@@ -764,12 +811,18 @@ class RunManagerBase(object):
         """
         Get the last run with a given status
 
+        if status is None or '' then return the
+        last run irrespective of the status.
+
         Args:
 
              status (str): Status of the tune
 
         """
         for r in self.runs:
+            if status in [None, 'any', '*', '']:
+                return r
+
             if r.status == status and not r.deleted:
                 return r
         return None
@@ -793,18 +846,22 @@ class PipelineConfig(object):
         self.siteconf = {}
         self.set_params()
 
+    def __str__(self):
+        return self.name
+
     def set_params(self):
 
         # Set parameters
         params = {
             'name': self.spec['name'],
             'enrich_root': os.environ['ENRICH_ROOT'],
+            'enrich_run_root': os.environ.get('ENRICH_RUN_ROOT',
+                                              os.environ['ENRICH_ROOT']),
             'enrich_customers_dir': os.environ['ENRICH_CUSTOMERS'],
             'enrich_data_dir': os.environ['ENRICH_DATA']
         }
 
-        for attr in ['customer_root', 'data_root',
-                     'output']:
+        for attr in ['customer_root', 'data_root', 'output']:
             params[attr] = self.spec[attr] % params
 
         # Handle aliases
