@@ -1387,6 +1387,17 @@ def test_create_state(params):
         print(greenbg('Module has testdata'))
         nextstep = True
 
+    try:
+        # If it is a lazy function, then call it now...
+        if nextstep and callable(obj.testdata):
+            obj.testdata = obj.testdata()
+    except:
+        print(redbg('Module could not load test data'))
+        nextstep = False
+
+    if not nextstep:
+        return nextstep
+
     if hasattr(obj, 'testdata'):
         if (('data' not in obj.testdata) or
             (not isinstance(obj.testdata['data'], dict))):
@@ -2551,7 +2562,19 @@ def test_task_create_state(params):
         print(greenbg('Module has testdata'))
         nextstep = True
 
+
     if hasattr(obj, 'testdata'):
+        # If callable, then call it...
+        try:
+            if callable(obj.testdata):
+                obj.testdata = obj.testdata()
+        except:
+            print(redbg('Module could not load test data'))
+            nextstep = False
+
+        if not nextstep:
+            return nextstep
+
         if (('data' not in obj.testdata) or
             (not isinstance(obj.testdata['data'], dict))):
             print(redbg("Module's testdata should have dict 'data' element"))
